deeponion-x13-hash
===========================

Python module for DeepOnion's X13 hashing.


Install
-------

Python is required as well as gcc.

    $ python setup.py install


Test
-------

After installation, test hash.

    $ python test.py
